from django.apps import AppConfig


class MapConfig(AppConfig):
    name = 'Zephyrus.map'
